/*
 Copyright (c) 1997 by Columbia University. All rights reserved.
 */
package tjt.util;
import java.awt.*;

/** 
 * A reusable message box object to display up to three short messages to 
 * the user. The dialog has one OK button to dismiss the message box.
 * @version 1.0 31 Aug 1998
 * @author Terrence Truta
 */
public class MsgDialog extends Dialog
{
    
  public MsgDialog(Frame parent, String title, String msg1, boolean modal) {
	  this(parent, modal);
	  setTitle(title);
	  label1.setText(msg1);
	}

	public MsgDialog(Frame parent, String title, String msg1, String msg2, boolean modal) {
	    this(parent, modal);
	    setTitle(title);
	    label1.setText(msg1);
		label2.setText(msg2);
	}
	
	public MsgDialog(Frame parent, String title, String msg1, String msg2, 
	                 String msg3, boolean modal) {
	    this(parent, modal);
	    setTitle(title);
	    label1.setText(msg1);
		label2.setText(msg2);
		label3.setText(msg3);
	}
    
	public MsgDialog(Frame parent, boolean modal)
	{
		super(parent, modal);

		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		setLayout(null);
		setVisible(false);
		setSize(332,142);
		btnOK = new java.awt.Button();
		btnOK.setLabel("OK");
		btnOK.setBounds(141,96,52,25);
		add(btnOK);
		label1 = new java.awt.Label("");
		label1.setBounds(35,24,262,20);
		add(label1);
		label2 = new java.awt.Label("");
		label2.setBounds(35,44,262,20);
		add(label2);
		label3 = new java.awt.Label("");
		label3.setBounds(35,64,262,20);
		add(label3);
		setTitle("Message");
		//}}

		//{{REGISTER_LISTENERS
		SymWindow aSymWindow = new SymWindow();
		this.addWindowListener(aSymWindow);
		SymAction lSymAction = new SymAction();
		btnOK.addActionListener(lSymAction);
		//}}
	}
	
	/**
	 * Adds a message to a label on the message box. 
	 * @param msg - Message to add to the Dialog
	 */
	public void addMsg(String msg) {
		if (((label1.getText()).trim()).compareTo("") == 0) 
		   label1.setText(msg);
	  else 
			if (((label2.getText()).trim()).compareTo("") == 0) 
				label2.setText(msg);
			else
				if (((label3.getText()).trim()).compareTo("") == 0)
					label3.setText(msg);
	}



	public void addNotify()
	{
  	    // Record the size of the window prior to calling parents addNotify.
	    Dimension d = getSize();

		super.addNotify();

		if (fComponentsAdjusted)
			return;

		// Adjust components according to the insets
		setSize(getInsets().left + getInsets().right + d.width, getInsets().top + getInsets().bottom + d.height);
		Component components[] = getComponents();
		for (int i = 0; i < components.length; i++)
		{
			Point p = components[i].getLocation();
			p.translate(getInsets().left, getInsets().top);
			components[i].setLocation(p);
		}
		fComponentsAdjusted = true;
	}

    // Used for addNotify check.
	boolean fComponentsAdjusted = false;


	public MsgDialog(Frame parent, String title, boolean modal)
	{
		this(parent, modal);
		setTitle(title);
	}

    /**
     * Shows or hides the component depending on the boolean flag b.
     * @param b  if true, show the component; otherwise, hide the component.
     * @see java.awt.Component#isVisible
     */
    public void setVisible(boolean b)
	{
		if(b)
		{
			Rectangle bounds = getParent().getBounds();
			Rectangle abounds = getBounds();
	
			setLocation(bounds.x + (bounds.width - abounds.width)/ 2,
				 bounds.y + (bounds.height - abounds.height)/2);
		}
		super.setVisible(b);
	}

	//{{DECLARE_CONTROLS
	java.awt.Button btnOK;
	java.awt.Label label1;
	java.awt.Label label2;
	java.awt.Label label3;
	//}}

	class SymWindow extends java.awt.event.WindowAdapter
	{
		public void windowClosing(java.awt.event.WindowEvent event)
		{
			Object object = event.getSource();
			if (object == MsgDialog.this)
				Dialog1_WindowClosing(event);
		}
	}
	
	void Dialog1_WindowClosing(java.awt.event.WindowEvent event)
	{
		setVisible(false);
	}

	class SymAction implements java.awt.event.ActionListener
	{
		public void actionPerformed(java.awt.event.ActionEvent event)
		{
			Object object = event.getSource();
			if (object == btnOK)
				btnOK_ActionPerformed(event);
		}
	}

	void btnOK_ActionPerformed(java.awt.event.ActionEvent event)
	{
		// to do: code goes here.
			 
		//{{CONNECTION
		// Hide the Dialog
		setVisible(false);
		//}}
	}
}
